<shader>

	<meta name="vertex-main">
<![CDATA[

attribute vec4 i_vertex;
attribute vec3 i_normal;
attribute vec2 i_texcoord0;

varying vec4 v_texcoord;
varying vec4 v_reflectParams; // amount

uniform mat4 g_worldViewProjMtx;
uniform mat4 g_worldMtx;
uniform mat4 g_textureMtx;

uniform vec3 g_cameraPos;

void main()
{
	gl_Position = g_worldViewProjMtx * i_vertex;
	
	v_texcoord.xy = ( g_textureMtx * vec4( i_texcoord0, 0, 1 ) ).xy;
	
	vec3 toCamera = normalize( g_cameraPos - ( g_worldMtx * i_vertex ).xyz );
	vec3 normal = normalize( ( g_worldMtx * vec4( i_normal, 0 ) ).xyz );
	
	v_texcoord.zw = reflect( toCamera, normal ).xy * 0.5 + 0.5;
	
	v_reflectParams = vec4( 0.0, 0.0, 0.0, 0.0 );
	v_reflectParams.x = max( 0.0, dot( toCamera, normal ) );
	v_reflectParams.x = v_reflectParams.x * v_reflectParams.x;
	v_reflectParams.x = v_reflectParams.x * v_reflectParams.x;
	v_reflectParams.x = ( 1.0 - min( 1.0, v_reflectParams.x * 2.0 ) ) * 0.75 + 0.25;
}

]]>
	</meta>
	
		<meta name="fragment-main">
<![CDATA[
varying vec4 v_texcoord;
varying vec4 v_reflectParams;

uniform vec4 g_instColor;
uniform sampler2D u_baseMap;
uniform sampler2D u_reflectionMap;

void main()
{
	vec4 baseMap = texture2D( u_baseMap, v_texcoord.xy );
	vec4 reflectMap = texture2D( u_reflectionMap, v_texcoord.zw );
	
	baseMap.rgb += reflectMap.rgb * v_reflectParams.x;
	//baseMap.rgb = reflectMap.rgb;
	gl_FragColor = baseMap * g_instColor;
}

]]>
	</meta>
	
	<meta name="fragment-header-gles2">
<![CDATA[
precision lowp float;
]]>
	</meta>
	
	<!-- ************************* gl2x ************************* -->
	<implement name="gl2x">
		<vertex>
			<merge meta="vertex-main" />
		</vertex>
		<fragment>
			<merge meta="fragment-main" />
		</fragment>
	</implement>
	
	<!-- ************************* gles2 ************************* -->
	<implement name="gles2">
		<vertex>
			<merge meta="vertex-main" />
		</vertex>
		<fragment>
			<merge meta="fragment-header-gles2" />
			<merge meta="fragment-main" />
		</fragment>
	</implement>
	
	<!-- ************************* uniforms ************************* -->
	<uniform type="Tex" name="u_baseMap" uiname="Base Map" value="" />
	<uniform type="Tex" name="u_reflectionMap" uiname="Reflection Map" value="" />
	
</shader>