<shader>

	<meta name="vertex-main">
<![CDATA[
attribute vec4 i_vertex;
attribute vec2 i_texcoord0;
attribute vec2 i_texcoord1;

varying vec4 v_texcoord;

uniform mat4 u_worldViewProjMtx;
uniform mat4 u_textureMtx;

void main() {
	gl_Position = u_worldViewProjMtx * i_vertex;
	v_texcoord.xy = (u_textureMtx * vec4(i_texcoord0, 0, 1)).xy;
	v_texcoord.zw = i_texcoord1;
}

]]>
	</meta>
	
	<meta name="fragment-combine_color-0">
<![CDATA[
vec4 combine_color( vec4 curr, vec4 color )
{
	return curr * color;
}
]]>
	</meta>
		
	<meta name="fragment-combine_color-1">
<![CDATA[
vec4 combine_color( vec4 curr, vec4 color )
{
	return vec4( curr.xyz + color.xyz, curr.w * color.w );
}
]]>
	</meta>
	
	<meta name="fragment-combine_color-2">
<![CDATA[
vec4 combine_color( vec4 curr, vec4 color )
{
	return vec4( mix( curr.xyz, color.xyz, color.w ), curr.w );
}
]]>
	</meta>

	<meta name="fragment-combine_color-3">
		<![CDATA[
vec4 combine_color( vec4 base, vec4 blend )
{
	vec4 ret;
	ret.r = (base.r < 0.5 ? (2.0 * base.r * blend.r) : (1.0 - 2.0 * (1.0 - base.r) * (1.0 - blend.r)));
	ret.g = (base.g < 0.5 ? (2.0 * base.g * blend.g) : (1.0 - 2.0 * (1.0 - base.g) * (1.0 - blend.g)));
	ret.b = (base.b < 0.5 ? (2.0 * base.b * blend.b) : (1.0 - 2.0 * (1.0 - base.b) * (1.0 - blend.b)));
	ret.a = base.a;
	return ret;
}
]]>
	</meta>

	<meta name="fragment-main">
<![CDATA[
varying vec4 v_texcoord;

uniform sampler2D u_basemap;
uniform sampler2D u_lightmap;
uniform vec4 u_color;
uniform vec4 u_lightmapScale;

void main()
{
	
	vec4 basemap = texture2D( u_basemap, v_texcoord.xy );
	vec4 lightmap = texture2D( u_lightmap, v_texcoord.zw );
	lightmap *= u_lightmapScale;
	
	vec4 o_color = combine_color( basemap, u_color );
	o_color.xyz *= lightmap.xyz;
	
	gl_FragColor = o_color;
}

]]>
	</meta>
	
	<meta name="fragment-header-gles2">
<![CDATA[
precision mediump float;
]]>
	</meta>

	<!-- ************************* gl2x-0 ************************* -->
	<implement name="gl2x-0">
		<vertex>
			<merge meta="vertex-main" />
		</vertex>
		<fragment>
			<merge meta="fragment-combine_color-0" />
			<merge meta="fragment-main" />
		</fragment>
	</implement>
	
	<!-- ************************* gl2x-1 ************************* -->
	<implement name="gl2x-1">
		<vertex>
			<merge meta="vertex-main" />
		</vertex>
		<fragment>
			<merge meta="fragment-combine_color-1" />
			<merge meta="fragment-main" />
		</fragment>
	</implement>
	
	<!-- ************************* gl2x-2 ************************* -->
	<implement name="gl2x-2">
		<vertex>
			<merge meta="vertex-main" />
		</vertex>
		<fragment>
			<merge meta="fragment-combine_color-2" />
			<merge meta="fragment-main" />
		</fragment>
	</implement>

	<!-- ************************* gl2x-3 ************************* -->
	<implement name="gl2x-3">
		<vertex>
			<merge meta="vertex-main" />
		</vertex>
		<fragment>
			<merge meta="fragment-combine_color-3" />
			<merge meta="fragment-main" />
		</fragment>
	</implement>
	
	<!-- ************************* gles2-0 ************************* -->
	<implement name="gles2-0">
		<vertex>
			<merge meta="vertex-main" />
		</vertex>
		<fragment>
			<merge meta="fragment-header-gles2" />
			<merge meta="fragment-combine_color-0" />
			<merge meta="fragment-main" />
		</fragment>
	</implement>
	
	<!-- ************************* gles2-1 ************************* -->
	<implement name="gles2-1">
		<vertex>
			<merge meta="vertex-main" />
		</vertex>
		<fragment>
			<merge meta="fragment-header-gles2" />
			<merge meta="fragment-combine_color-1" />
			<merge meta="fragment-main" />
		</fragment>
	</implement>
	
	<!-- ************************* gles2-2 ************************* -->
	<implement name="gles2-2">
		<vertex>
			<merge meta="vertex-main" />
		</vertex>
		<fragment>
			<merge meta="fragment-header-gles2" />
			<merge meta="fragment-combine_color-2" />
			<merge meta="fragment-main" />
		</fragment>
	</implement>

	<!-- ************************* gles2-3 ************************* -->
	<implement name="gles2-3">
		<vertex>
			<merge meta="vertex-main" />
		</vertex>
		<fragment>
			<merge meta="fragment-header-gles2" />
			<merge meta="fragment-combine_color-3" />
			<merge meta="fragment-main" />
		</fragment>
	</implement>
	
</shader>