<shader>

	<meta name="vertex-main">
<![CDATA[
attribute vec4 i_vertex;
attribute vec2 i_texcoord0;
attribute vec4 i_color;

varying vec2 v_texcoord;
varying MCD_LOWP vec4 v_color;

uniform mat4 u_worldViewProjMtx;
uniform mat4 u_textureMtx;

void main() 
{
	gl_Position = u_worldViewProjMtx * i_vertex;
	v_texcoord = ( u_textureMtx * vec4( i_texcoord0, 0, 1 ) ).xy;
	v_color = i_color;
}

]]>
	</meta>
	
	<meta name="fragment-combine_color-0">
<![CDATA[
vec4 combine_color( vec4 curr, vec4 color )
{
	return curr * color;
}
]]>
	</meta>
		
	<meta name="fragment-combine_color-1">
<![CDATA[
vec4 combine_color( vec4 curr, vec4 color )
{
	return vec4( curr.xyz + color.xyz, curr.w * color.w );
}
]]>
	</meta>

	<meta name="fragment-combine_vcolor-0">
<![CDATA[
vec4 combine_vcolor( vec4 curr, vec4 color )
{
	return curr * color;
}
]]>
	</meta>
		
	<meta name="fragment-combine_vcolor-1">
<![CDATA[
vec4 combine_vcolor( vec4 curr, vec4 color )
{
	return vec4( curr.xyz + color.xyz, curr.w * color.w );
}
]]>
	</meta>
	
	<meta name="fragment-main">
<![CDATA[
varying vec2 v_texcoord;
varying MCD_LOWP vec4 v_color;

uniform sampler2D u_tex;
uniform vec4 u_color;

void main() 
{
	
	vec4 o_color = texture2D( u_tex, v_texcoord );
	
	o_color = combine_color  ( o_color, u_color );
	o_color = combine_vcolor( o_color, v_color );
	
	gl_FragColor = o_color;
}

]]>
	</meta>
	
	<meta name="fragment-header-gles2">
<![CDATA[
precision lowp float;
]]>
	</meta>
	
	<!-- ************************* gl2x-00 ************************* -->
	<implement name="gl2x-00">
		<vertex>
			<merge meta="vertex-main" />
		</vertex>
		<fragment>
			<merge meta="fragment-combine_color-0" />
			<merge meta="fragment-combine_vcolor-0" />
			<merge meta="fragment-main" />
		</fragment>
	</implement>
	
	<!-- ************************* gl2x-01 ************************* -->
	<implement name="gl2x-01">
		<vertex>
			<merge meta="vertex-main" />
		</vertex>
		<fragment>
			<merge meta="fragment-combine_color-1" />
			<merge meta="fragment-combine_vcolor-0" />
			<merge meta="fragment-main" />
		</fragment>
	</implement>
	
	<!-- ************************* gl2x-10 ************************* -->
	<implement name="gl2x-10">
		<vertex>
			<merge meta="vertex-main" />
		</vertex>
		<fragment>
			<merge meta="fragment-combine_color-0" />
			<merge meta="fragment-combine_vcolor-1" />
			<merge meta="fragment-main" />
		</fragment>
	</implement>
	
	<!-- ************************* gl2x-11 ************************* -->
	<implement name="gl2x-11">
		<vertex>
			<merge meta="vertex-main" />
		</vertex>
		<fragment>
			<merge meta="fragment-combine_color-1" />
			<merge meta="fragment-combine_vcolor-1" />
			<merge meta="fragment-main" />
		</fragment>
	</implement>
	
	<!-- ************************* gles2-00 ************************* -->
	<implement name="gles2-00">
		<vertex>
			<merge meta="vertex-main" />
		</vertex>
		<fragment>
			<merge meta="fragment-header-gles2" />
			<merge meta="fragment-combine_color-0" />
			<merge meta="fragment-combine_vcolor-0" />
			<merge meta="fragment-main" />
		</fragment>
	</implement>
	
	<!-- ************************* gles2-01 ************************* -->
	<implement name="gles2-01">
		<vertex>
			<merge meta="vertex-main" />
		</vertex>
		<fragment>
			<merge meta="fragment-header-gles2" />
			<merge meta="fragment-combine_color-1" />
			<merge meta="fragment-combine_vcolor-0" />
			<merge meta="fragment-main" />
		</fragment>
	</implement>
	
	<!-- ************************* gles2-10 ************************* -->
	<implement name="gles2-10">
		<vertex>
			<merge meta="vertex-main" />
		</vertex>
		<fragment>
			<merge meta="fragment-header-gles2" />
			<merge meta="fragment-combine_color-0" />
			<merge meta="fragment-combine_vcolor-1" />
			<merge meta="fragment-main" />
		</fragment>
	</implement>
	
	<!-- ************************* gles2-11 ************************* -->
	<implement name="gles2-11">
		<vertex>
			<merge meta="vertex-main" />
		</vertex>
		<fragment>
			<merge meta="fragment-header-gles2" />
			<merge meta="fragment-combine_color-1" />
			<merge meta="fragment-combine_vcolor-1" />
			<merge meta="fragment-main" />
		</fragment>
	</implement>
	
</shader>